==> haskell-storablevector-0.2.13.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-storablevector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 storablevector
version:              0.2.13.1
visibility:           public
id:                   storablevector-0.2.13.1-4U4bmsZAlPN86lpdJkDW4y
key:                  storablevector-0.2.13.1-4U4bmsZAlPN86lpdJkDW4y
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storablevector@henning-thielemann.de>
author:
    Spencer Janssen <sjanssen@cse.unl.edu>, Henning Thielemann <storablevector@henning-thielemann.de>

stability:            Experimental
homepage:             http://www.haskell.org/haskellwiki/Storable_Vector
synopsis:
    Fast, packed, strict storable arrays with a list interface like ByteString

description:
    Fast, packed, strict storable arrays
    with a list interface,
    a chunky lazy list interface with variable chunk size
    and an interface for write access via the @ST@ monad.
    This is much like @bytestring@ and @binary@
    but can be used for every '\''Foreign.Storable.Storable'\'' type.
    See also package
    <http://hackage.haskell.org/package/vector>
    with a similar intention.

    We do not provide advanced fusion optimization,
    since especially for lazy vectors
    this would either be incorrect or not applicable.
    However we provide fusion with lazy lists in the package
    <http://hackage.haskell.org/package/storablevector-streamfusion>.

category:             Data
abi:                  fd651e05113cd936f1079c77dfe6e0e2
exposed:              True
exposed-modules:
    Data.StorableVector Data.StorableVector.Base
    Data.StorableVector.Lazy Data.StorableVector.Lazy.Builder
    Data.StorableVector.Lazy.Pattern Data.StorableVector.Lazy.Pointer
    Data.StorableVector.Lazy.Typed Data.StorableVector.Pointer
    Data.StorableVector.ST.Lazy Data.StorableVector.ST.Strict

hidden-modules:
    Data.StorableVector.Memory Data.StorableVector.ST.Private
    Data.StorableVector.Lazy.PointerPrivate
    Data.StorableVector.Lazy.PointerPrivateIndex
    Data.StorableVector.Cursor

import-dirs:          /usr/lib/ghc-8.10.1/site-local/storablevector-0.2.13.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/storablevector-0.2.13.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/storablevector-0.2.13.1
hs-libraries:         HSstorablevector-0.2.13.1-4U4bmsZAlPN86lpdJkDW4y
depends:
    QuickCheck-2.14-DFbHIKD0X9e1dD7ZrJGsRr base-4.14.0.0
    deepseq-1.4.4.0 non-negative-0.1.2-L6PdUAq6Wf0Cpllf9H40Dz
    syb-0.7.1-6kfNxsXCCuQCrpdoMzyi8K transformers-0.5.6.2
    unsafe-0.0-HGRo7VnJHUhGzO6vvgKeCz
    utility-ht-0.0.15-KzVaAdUwP82GP9rrO9tBGk

haddock-interfaces:
    /usr/share/doc/haskell-storablevector/html/storablevector.haddock

haddock-html:         /usr/share/doc/haskell-storablevector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storablevector-0.2.13.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-storablevector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 storablevector
version:              0.2.13.1
visibility:           public
id:                   storablevector-0.2.13.1-AoJYYQoiR55Esi1YgH4aqp
key:                  storablevector-0.2.13.1-AoJYYQoiR55Esi1YgH4aqp
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storablevector@henning-thielemann.de>
author:
    Spencer Janssen <sjanssen@cse.unl.edu>, Henning Thielemann <storablevector@henning-thielemann.de>

stability:            Experimental
homepage:             http://www.haskell.org/haskellwiki/Storable_Vector
synopsis:
    Fast, packed, strict storable arrays with a list interface like ByteString

description:
    Fast, packed, strict storable arrays
    with a list interface,
    a chunky lazy list interface with variable chunk size
    and an interface for write access via the @ST@ monad.
    This is much like @bytestring@ and @binary@
    but can be used for every '\''Foreign.Storable.Storable'\'' type.
    See also package
    <http://hackage.haskell.org/package/vector>
    with a similar intention.

    We do not provide advanced fusion optimization,
    since especially for lazy vectors
    this would either be incorrect or not applicable.
    However we provide fusion with lazy lists in the package
    <http://hackage.haskell.org/package/storablevector-streamfusion>.

category:             Data
abi:                  93879f3837c9aa900fe74904a1b39a88
exposed:              True
exposed-modules:
    Data.StorableVector Data.StorableVector.Base
    Data.StorableVector.Lazy Data.StorableVector.Lazy.Builder
    Data.StorableVector.Lazy.Pattern Data.StorableVector.Lazy.Pointer
    Data.StorableVector.Lazy.Typed Data.StorableVector.Pointer
    Data.StorableVector.ST.Lazy Data.StorableVector.ST.Strict

hidden-modules:
    Data.StorableVector.Memory Data.StorableVector.ST.Private
    Data.StorableVector.Lazy.PointerPrivate
    Data.StorableVector.Lazy.PointerPrivateIndex
    Data.StorableVector.Cursor

import-dirs:          /usr/lib/ghc-8.10.1/site-local/storablevector-0.2.13.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/storablevector-0.2.13.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/storablevector-0.2.13.1
hs-libraries:         HSstorablevector-0.2.13.1-AoJYYQoiR55Esi1YgH4aqp
depends:
    QuickCheck-2.14.1-LOwLcMvuV7vGwZlhSRTd6I base-4.14.0.0
    deepseq-1.4.4.0 non-negative-0.1.2-Jnsm1D4X9eFAVDO2OyIpLt
    syb-0.7.1-6kfNxsXCCuQCrpdoMzyi8K transformers-0.5.6.2
    unsafe-0.0-HGRo7VnJHUhGzO6vvgKeCz
    utility-ht-0.0.15-KzVaAdUwP82GP9rrO9tBGk

haddock-interfaces:
    /usr/share/doc/haskell-storablevector/html/storablevector.haddock

haddock-html:         /usr/share/doc/haskell-storablevector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
